@@ -81,6 +81,9 @@ func newMigrateToV2() *cobra.Command {
 			Hidden:      true,
 		},
 	)
+
+	cmd.AddCommand(newTroubleshoot())
+
 	return cmd
 }
 
@@ -195,6 +198,7 @@ type v2PlatformMigrator struct {
 	isPostgres              bool
 	pgConsulUrl             string
 	targetImg               string
+	backupMachines          map[string]int
 	verbose                 bool
 }
 
@@ -314,6 +318,7 @@ func NewV2PlatformMigrator(ctx context.Context, appName string) (V2PlatformMigra
 		recovery: recoveryState{
 			platformVersion: appFull.PlatformVersion,
 		},
+		backupMachines: map[string]int{},
 	}
 	if migrator.isPostgres {
 		consul, err := apiClient.EnablePostgresConsul(ctx, appCompact.Name)
@@ -439,9 +444,44 @@ func (m *v2PlatformMigrator) Migrate(ctx context.Context) (err error) {
 				header = "(!) An error has occurred. Attempting to rollback changes..."
 			}
 			fmt.Fprintf(m.io.ErrOut, "failed while migrating: %v\n", err)
-			recoveryBlock := render.NewTextBlock(ctx, header)
-			if recoveryErr := m.rollback(ctx, recoveryBlock); recoveryErr != nil {
-				fmt.Fprintf(m.io.ErrOut, "failed while rolling back application: %v\n", recoveryErr)
+
+			canSuggestTroubleshooting := !flag.GetYes(ctx) && m.io.IsInteractive()
+			if err == abortedErr || strings.Contains(err.Error(), "failed to launch VM: To create more than") {
+				canSuggestTroubleshooting = false
+			}
+
+			enterTroubleshooting := false
+			if canSuggestTroubleshooting {
+				askErr := survey.AskOne(&survey.Confirm{
+					Message: "Would you like to enter interactive troubleshooting mode? If not, the migration will be rolled back.",
+					Default: true,
+				}, &enterTroubleshooting)
+				if askErr != nil {
+					enterTroubleshooting = false
+				}
+			}
+
+			if enterTroubleshooting {
+
+				migrateErr := func() error {
+					t, err := newTroubleshooter(ctx, m.appCompact.Name)
+					if err != nil {
+						return err
+					}
+
+					return t.run(ctx)
+				}()
+				if migrateErr != nil {
+					fmt.Fprintf(m.io.ErrOut, "failed while troubleshooting: %v\n", err)
+				} else {
+					err = nil // Printing an error message below a successful troubleshooting run is confusing
+				}
+
+			} else {
+				recoveryBlock := render.NewTextBlock(ctx, header)
+				if recoveryErr := m.rollback(ctx, recoveryBlock); recoveryErr != nil {
+					fmt.Fprintf(m.io.ErrOut, "failed while rolling back application: %v\n", recoveryErr)
+				}
 			}
 		}
 	}()
@@ -671,10 +711,6 @@ func (m *v2PlatformMigrator) validate(ctx context.Context) error {
 		return fmt.Errorf("failed to validate config for Apps V2 platform: %w", err)
 	}
 
-	err = m.validateScaling(ctx)
-	if err != nil {
-		return err
-	}
 	err = m.validateVolumes(ctx)
 	if err != nil {
 		return err
@@ -700,14 +736,7 @@ func (m *v2PlatformMigrator) validateKnownUnmigratableApps(ctx context.Context)
 	if slices.Contains(knownUnmigratableApps, m.appCompact.ID) {
 		return fmt.Errorf("Your app uses features incompatible with the V2 platform. Please contact support to discuss how to successfully migrate")
 	}
-	return nil
-}
 
-func (m *v2PlatformMigrator) validateScaling(ctx context.Context) error {
-	// FIXME: for now we fail if there is autoscaling.. remove this once we create any extra machines based on autoscaling config
-	if m.autoscaleConfig.Enabled {
-		return fmt.Errorf("cannot migrate app %s with autoscaling config, yet; watch https://community.fly.io for announcements about autoscale support with migrations", m.appCompact.Name)
-	}
 	return nil
 }
 
@@ -898,6 +927,18 @@ func (m *v2PlatformMigrator) ConfirmChanges(ctx context.Context) (bool, error) {
 		fmt.Fprintf(m.io.Out, "   * Create %d \"%s\" machine%s\n", count, name, s)
 	}
 
+	if len(m.backupMachines) > 0 {
+
+		fmt.Fprintf(m.io.Out, " * Create autostop machines, copying the configuration of each existing VM\n")
+		for name, count := range m.backupMachines {
+			s := "s"
+			if count == 1 {
+				s = ""
+			}
+			fmt.Fprintf(m.io.Out, "   * Create %d \"%s\" autostop machine%s\n", count, name, s)
+		}
+	}
+
 	if m.isPostgres {
 		fmt.Fprintf(m.io.Out, " * Wait for at least one new in-region PG replica to become synced\n")
 	}
