@@ -172,8 +172,15 @@ func UpgradeInPlace(ctx context.Context, io *iostreams.IOStreams, prelease bool)
 
 	if !ok {
 		if runtime.GOOS == "windows" {
-			shellToUse = "powershell.exe"
-			switchToUse = "-Command"
+			// pwsh.exe is the name of the PowerShell executable from 6.0+
+			// powershell.exe is locked to 5.1 forever
+			if commandInPath("pwsh.exe") {
+				shellToUse = "pwsh.exe"
+				switchToUse = "-Command"
+			} else {
+				shellToUse = "powershell.exe"
+				switchToUse = "-Command"
+			}
 		} else {
 			shellToUse = "/bin/bash"
 		}
@@ -192,6 +199,17 @@ func UpgradeInPlace(ctx context.Context, io *iostreams.IOStreams, prelease bool)
 	return cmd.Run()
 }
 
+func commandInPath(command string) bool {
+	for _, dir := range filepath.SplitList(os.Getenv("PATH")) {
+		path := filepath.Join(dir, command)
+		if _, err := os.Stat(path); err == nil {
+			return true
+		}
+	}
+
+	return false
+}
+
 // can't replace binary on windows, need to move
 func renameCurrentBinaries() error {
 	binaries, err := currentWindowsBinaries()
@@ -209,13 +227,18 @@ func renameCurrentBinaries() error {
 }
 
 func currentWindowsBinaries() ([]string, error) {
-	binaryPath, err := os.Executable()
+	execPath, err := os.Executable()
+	if err != nil {
+		return nil, err
+	}
+
+	canonicalPath, err := filepath.EvalSymlinks(execPath)
 	if err != nil {
 		return nil, err
 	}
 
 	return []string{
-		binaryPath,
-		filepath.Join(filepath.Dir(binaryPath), "wintun.dll"),
+		canonicalPath,
+		filepath.Join(filepath.Dir(canonicalPath), "wintun.dll"),
 	}, nil
 }
